package org.jabricks.basegui.examples;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

import javax.swing.*;
import javax.swing.tree.TreeNode;

import org.jabricks.basegui.tree.ITree;
import org.jabricks.basegui.tree.ITreeListener;
import org.jabricks.basegui.tree.Tree;
import org.jabricks.basegui.tree.TreeRecord;

class Good extends TreeRecord 
{
	private Float quantity;
	private Float cost    ;
	
	public Float getQuantity(){
		return quantity;
	}
	public void setQuantity(Float quantity) {
		this.quantity = quantity;
	}
	public Float getCost() {
		return cost;
	}
	public void setCost(Float cost) {
		this.cost = cost;
	}
}
public class ExampleTree extends JFrame implements ITreeListener
{
	private static final long serialVersionUID = 1L;

	private ITree tree = null;
	
	private Object[][] goods = 
		       {{ 0, 0, "Список товаров", null, null},
			    { 1, 0, "Продукты"      , null, null},
                {11, 1, "Хлеб дарницкий",  0.4f, 40f},
                {12, 1, "Батон нарезной",  0.3f, 32f},
                {13, 1, "Сметана"       ,  0.3f, 48f},
                { 2, 0, "Промтовары"    , null, null},
                { 3, 2, "Для дома"      , null, null},
                {31, 3, "Лампочки"      ,  35f, 140f},
                {31, 3, "Батарейки"     ,  45f, 90f},
                { 4, 2, "Для дачи"      , null, null},
                {41, 4, "Замок"         , 600f, 600f},
                {42, 4, "Грабли"        , 290f, 290f}};
	private int        added_idx = 0; 
	private Object[][] goods_add = 
               {{ 5, 2, "Инструмент"    , null, null},
			    {50, 5, "Шуруповерт"    , 7800f, 7800f},
			    {51, 5, "Перфоратор"    , 9000f, 9000f}};
	
	private final String IMG_path = "images/document.png";
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private Good createGood(final Object[] object)
	{
		Good good = new Good();
		good.setId      ((int   ) object[0]);
		good.setPid     ((int   ) object[1]);
		good.setName    ((String) object[2]);
		good.setQuantity((Float ) object[3]);
		good.setCost    ((Float ) object[4]);
		return good;
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	public ExampleTree()
	{
		super("Tree example");
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		
        createGUI();
    	List<TreeRecord> list = new ArrayList<TreeRecord>();
    	for (int i = 0; i < goods.length; i++) {
    		Good good = createGood(goods[i]);
    		list.add(good);
    	}
    	tree.loadData(list);

		setSize(520, 360);
		setVisible(true);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createGUI()
	{
    	tree = new Tree(this);

		File file = new File(IMG_path);
		if (file.exists()) {
			ImageIcon image = new ImageIcon(IMG_path);
			tree.setLeafIcon(image);
		}

		JButton btnAdd = new JButton("Добавить запись");
		btnAdd.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				addRecord();
			}
		});
		
		JButton btnDel = new JButton("Удалить запись");
		btnDel.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				deleteRecord();
			}
		});
		// Панель кнопок управления
		JPanel pnlButtons = new JPanel();
		pnlButtons.add(btnAdd);
		pnlButtons.add(btnDel);

		Container container = getContentPane();
		container.add(tree.asWidget(), BorderLayout.CENTER);
		container.add(pnlButtons     , BorderLayout.SOUTH);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	@Override
	public void onClickNode(TreeRecord record)
	{
        // Выделенный объект
		Good good = (Good)record;
		String title = "Выделенная запись"; 
		String msg = "id=" + good.getId()
				   + ", pid=" + good.getPid()
				   + ", name=" + good.getName();
		JOptionPane.showMessageDialog(ExampleTree.this, 
				"Вы выбрали запись : \n" + msg,
				title, JOptionPane.INFORMATION_MESSAGE);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	/**
	 * Процедура добавления записи
	 */
	private void addRecord()
	{
		if (added_idx > (goods_add.length - 1))
			return;
		Good good = (Good)tree.getSelectedNodeObject();
		if (added_idx == 0) {
			if (good.getId() != 2) {
				String title = "Ошибка"; 
				String msg = "Выделите запись 'Промтовары' и "
						   + "нажмите кнопку 'Добавить'";
				JOptionPane.showMessageDialog(ExampleTree.this,
						msg, title, 
                        JOptionPane.INFORMATION_MESSAGE);
			} else {
				good = createGood(goods_add[added_idx]);
				tree.addNodeObject(good);
				added_idx++;					
			}
		} else {
			good = createGood(goods_add[added_idx]);
			tree.addNodeObject(good);
			added_idx++;					
		}
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	/**
	 * Процедура удаления записи из таблицы
	 */
	private void deleteRecord()
	{
		// Выделенная запись
    	TreeNode node = tree.getSelectedNode();
		if ((node != null) && (node.getChildCount() == 0))
			tree.deleteNodeObject(node);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	public static void main(String[] args) {
		new ExampleTree();
	}
}